import { FormGroup, FormArray } from '@angular/forms';
import * as i0 from "@angular/core";
/**
 * A simple service that provides convenience methods for forms.
 *
 * @overviewDetails
 * #### Features
 *
 * Currently the only method available is `markAsTouched`. This will iterate
 * through the controls of given form and mark them all as touched. Mainly
 * intended to cause change detection so potential error messages are rendered
 * for all controls on the given form where appropriate, allowing for nested
 * FormGroups and FormArrays.
 *
 * #### Basic Usage Example
 * ```typescript
 * // ...
 * import {FormService} from '@ngx-material-dashboard/widgets';
 * // ...
 * constructor(private formService: FormService) {}
 *
 * submit(form: FormGroup | FormArray): void {
 *     this.formService.markAsTouched(form);
 * }
 * ```
 */
export declare class FormService {
    /**
     * Iterates through the controls of the given form and marks them as touched.
     * Mainly intended to display error messages on form. Allows for nested
     * FormGroups and FormArrays. Taken from below stackoverflow response.
     * https://stackoverflow.com/a/50992362
     *
     * @param form The form group or array to mark as touched.
     */
    markAsTouched(form: FormGroup | FormArray): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FormService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FormService>;
}
