/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
import { OnInit } from '@angular/core';
import { Subscription } from 'rxjs';
import { LoadingService } from '../../services/loading.service';
import * as i0 from "@angular/core";
/**
 * A wrapper component for `MatProgressSpinner` that only displays the spinner
 * when HTTP requests are in progress. This component is automatically included
 * in the `DefaultLayout`, so there is no need to include this yourself if you
 * are using that.
 *
 * You may use this component if you are not using the `DefaultLayout`. The
 * `LoadingService` must be conigured for this component to work correctly. See
 * the [LoadingService](/widgets/layout/overview#loading-service) documentation for more info.
 *
 *  @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-loading></ngx-mat-default-loading>
 * <!-- any additional tags -->
 * ```
 * ```typescript
 * import {Component} from '@angular/core';
 *
 * @Component({
 *     selector: 'basic-usage-example',
 *     templateUrl: './basic-usage-example.html'
 * })
 * export class BasicUsageExample {}
 * ```
 */
export declare class LoadingComponent implements OnInit {
    private loadingService;
    /** Boolean indicating whether or not to display loading spinner. */
    loading: boolean;
    /** The subscriptions for the component. */
    sub: Subscription;
    constructor(loadingService: LoadingService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<LoadingComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<LoadingComponent, "ngx-mat-loading", never, {}, {}, never, never>;
}
