/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
import { EventEmitter } from '@angular/core';
import { MatSidenav } from '@angular/material/sidenav';
import { HeaderComponent } from '../../components/header/header.component';
import { SidenavItem } from '../../interfaces/sidenav.interface';
import * as i0 from "@angular/core";
/**
 * Defines the default layout for the app, which consists of the header, footer,
 * and main content based on the current route. The layout should have a sticky
 * footer, meaning if the main content is not tall enough to fill the existing
 * space, then the footer will stick to the bottom of the page.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-default-layout [logo]="logo" [sidenavItems]="sidenavItems">
 *  </ngx-mat-default-layout>
 * ```
 * ```typescript
 * import {Component} from '@angular/core';
 * import {SidenavItem} from '@ngx-material-dashboard/widgets';
 *
 * @Component({
 *     selector: 'basic-usage-example',
 *     templateUrl: './basic-usage-example.html'
 * })
 * export class BasicUsageExample {
 *     logo = 'My Tasks';
 *     sidenavItems: SidenavItem[] = [
 *         { queryParams: { isComplete: false }, route: ['tasks'], text: 'Pending', selector: 'pending' },
 *         { queryParams: { isComplete: false, filter: 'overdue' }, route: ['tasks'], text: 'Over Due', selector: 'over-due' },
 *         { queryParams: { isComplete: true }, route: ['tasks'], text: 'Complete', selector: 'complete' }
 *     ];
 * }
 * ```
 */
export declare class DefaultLayoutComponent {
    /** Text to display next to copyright date. */
    company: string;
    /** The main "logo" text for the app to display in the header. */
    logo: string;
    /** The mode for the drawer (i.e. 'over', 'push', 'side', or 'rail'). */
    mode: any;
    /** List of items to render in the sidenav. */
    sidenavItems: SidenavItem[];
    /** Boolean indicating whether the screen size is small (defaults to false). */
    isSmallScreen: boolean;
    /** Event emitted when user clicks search button in filter. */
    clickSearch: EventEmitter<boolean>;
    header: HeaderComponent;
    /** The sidenav defined in the template. */
    sidenav: MatSidenav;
    /** Boolean indicating  */
    opened: boolean;
    /**
     * Handler for when the user clicks the search button in the filter.
     *
     * @param res Boolean value to indicate if search button was clicked.
     */
    onSearchFilterClick(res: boolean): void;
    /**
     * Toggles the sidenav.
     */
    toggleSidenav(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DefaultLayoutComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DefaultLayoutComponent, "ngx-mat-default-layout", never, { "company": "company"; "logo": "logo"; "mode": "mode"; "sidenavItems": "sidenavItems"; "isSmallScreen": "isSmallScreen"; }, { "clickSearch": "clickSearch"; }, never, ["[filter]"]>;
}
