import { JsonModel } from '@ngx-material-dashboard/base-json';
import { CollectionComponent } from '../../../collection/components/collection/collection.component';
import * as i0 from "@angular/core";
/**
 * The `List` extends `Collection` and is meant for rendering items in a list.
 * A `Sorter` is rendered above the data list, which is meant to allow users to
 * well sort the data in the list based on the provided `field` options users
 * should be able to sort the data on.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-list [data]="data" [fields]="fields">
 *     <ng-template #model let-model="model">
 *        <mat-card>
 *            <mat-card-title>
 *                {{model.id}} Title
 *            </mat-card-title>
 *            <mat-card-content>
 *                Content for dummy object {{model.id}}
 *            </mat-card-content>
 *       </mat-card>
 *     </ng-template>
 * </ngx-mat-list>
 * ```
 * ```typescript
 * @Component({
 *     selector: 'basic-list-usage-example',
 *     templateUrl: './basic-list-usage-example.html'
 * }) export class BasicListUsageExample {
 *     data: Task[] = [...];
 *     fields: string[] = ['id'];
 * }
 * ```
 */
export declare class ListComponent<T extends JsonModel> extends CollectionComponent<T> {
    static ɵfac: i0.ɵɵFactoryDeclaration<ListComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ListComponent<any>, "ngx-mat-list", never, {}, {}, never, never>;
}
