/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
import { AfterViewInit, ElementRef, EventEmitter } from '@angular/core';
import { IconDefinition } from '@fortawesome/free-solid-svg-icons';
import * as i0 from "@angular/core";
/**
 * A drop down component for filtering data. The component includes all tags
 * and buttons necessary to render the drop down menu and filter data. This is
 * included with the `PagedTableWithToolbar`, and all logic is included to
 * handle filtering your data when the user clicks the `Search` button. The only
 * thing you must provide is a form with one or more fields to filter your data.
 * See the [PagedTableWithToolbar](/widgets/table/overview#paged-table-with-toolbar-component)
 * for more details.
 *
 * > NOTE: The key for each control included in the form should match up with
 * > expected filter values to be included in query parameters sent to your API.
 * > This allows a map to be generated dynamically by looping over controls,
 * > rather than requiring parent component to define filter map (which can get
 * > repetative).
 */
export declare class FilterDropDownComponent implements AfterViewInit {
    clearSearchForm: EventEmitter<boolean>;
    /** The event emitted when the user clicks the search button. */
    searchClick: EventEmitter<boolean>;
    /** A reference to the search field in the component. */
    field: ElementRef<HTMLElement>;
    /** The icon used to open the drop down. */
    faCaretDown: IconDefinition;
    /** The icon to display next to search text. */
    faSearch: IconDefinition;
    /** The width of the menu. */
    menuWidth: any;
    constructor();
    ngAfterViewInit(): void;
    clear(): void;
    search(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterDropDownComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FilterDropDownComponent, "ngx-mat-filter-drop-down", never, {}, { "clearSearchForm": "clearSearchForm"; "searchClick": "searchClick"; }, never, ["*"]>;
}
